# check50 [![Build Status](https://www.travis-ci.org/cs50/check50.svg?branch=develop)](https://www.travis-ci.org/cs50/check50)

check50 is a testing tool for checking student code. As a student you can use check50 to check your CS50 problem sets or any other Problem sets for which check50 checks exist. check50 allows teachers to automatically grade code on correctness and to provide automatic feedback while students are coding.

You can find documentation and instructions for writing your own checks at https://cs50.readthedocs.io/check50/.

